@@ -18,4 +18,4 @@ mod state;
 // Export current sdk types for downstream users building with a different sdk version
 pub use solana_program;
 
-solana_program::declare_id!("TokenLending1111111111111111111111111111111");
+solana_program::declare_id!("PrtedjXEcbH2SCgvL1oA1rFGxAr2UgZvqxQGxN2ErDT");
